@@ -11,7 +11,7 @@
  *
  * Needs Javascript
  */
-define('SM_PATH','../../');
+if (!defined('SM_PATH'))define('SM_PATH','../../');
 
 include_once(SM_PATH . 'include/validate.php');
 include_once(SM_PATH . 'functions/date.php');
