@@ -11,15 +11,13 @@
  *
  * NOTE: Modified from addrbook_search from /functions/
  */
-
-define('SM_PATH','../../');
+if (!defined('SM_PATH'))define('SM_PATH','../../');
 
 include_once(SM_PATH . 'include/validate.php');
 
 /* List search results */
 function display_result($res, $includesource = true, $javascript_on=true) {
     global $color, $abook, $srch_rslt_lines;
-        
     if(sizeof($res) <= 0) return;
         
     $line = 0;
@@ -64,6 +62,28 @@ include_once(SM_PATH . 'functions/addressbook.php');
 include_once(SM_PATH . 'plugins/abook_group/abook_group_database.php');
 include_once(SM_PATH . 'plugins/abook_group/abook_group_functions.php');
     
+/*  Start Globals  */
+
+sqgetGlobalVar('srch_rslt_lines', $srch_rslt_lines, SQ_POST);
+sqgetGlobalVar('color', $color, SQ_POST);
+sqgetGlobalVar('abook', $abook, SQ_POST);
+sqgetGlobalVar('query', $query, SQ_POST);
+sqgetGlobalVar('show', $show, SQ_POST);
+sqgetGlobalVar('listall', $listall, SQ_POST);
+sqgetGlobalVar('addNewGroup', $addNewGroup, SQ_POST);
+sqgetGlobalVar('addToGroup', $addToGroup, SQ_POST);
+sqgetGlobalVar('backend', $backend, SQ_POST);
+sqgetGlobalVar('newGroup', $newGroup, SQ_POST);
+sqgetGlobalVar('nickNameBackEnd', $nickNameBackEnd, SQ_POST);
+sqgetGlobalVar('abookGroups', $abookGroups, SQ_POST);
+sqgetGlobalVar('userData', $userData, SQ_POST);
+sqgetGlobalVar('myGroups', $myGroups, SQ_POST);
+sqgetGlobalVar('groupName', $groupName, SQ_POST);
+sqgetGlobalVar('myparams', $myparams, SQ_POST);
+sqgetGlobalVar('group', $group, SQ_POST);
+
+/*  End Globals  */
+
 $myparams = array();
 $myparams['dsn'] = $addrbook_dsn;
 $myparams['table'] = 'addressgroups';
@@ -75,7 +95,6 @@ $abookGroups->global_abook_table = "globaladdress";
 
 //displayHtmlHeader();
 displayPageHeader($color, $mailbox);
-    
 /* Initialize vars */
 if (!isset($query) || isset($listall)) { $query = ''; }
 if (!isset($show))  { $show  = ''; }
