@@ -8,8 +8,7 @@
  *
  * List Group members
  */
-
-define('SM_PATH','../../');
+if (!defined('SM_PATH'))define('SM_PATH','../../');
 
 include_once(SM_PATH . 'include/validate.php');
 include_once(SM_PATH . 'functions/date.php');
@@ -20,9 +19,29 @@ include_once(SM_PATH . 'functions/strings.php');
 include_once(SM_PATH . 'plugins/abook_group/abook_group_database.php');
 include_once(SM_PATH . 'plugins/abook_group/abook_group_functions.php');
 
+
 /* --- End functions --- */
 
 global $mailbox, $username;
+
+/* Set globals */
+sqgetGlobalVar('username', $username, SQ_POST);
+sqgetGlobalVar('mailbox', $mailbox, SQ_POST);
+sqgetGlobalVar('myparams', $myparams, SQ_POST);
+sqgetGlobalVar('abook', $abook, SQ_POST);
+sqgetGlobalVar('nickNameBackEnd', $nickNameBackEnd, SQ_POST);
+sqgetGlobalVar('userData', $userData, SQ_POST);
+sqgetGlobalVar('groupName', $groupName, SQ_GET);
+sqgetGlobalVar('message', $message, SQ_POST);
+sqgetGlobalVar('myGroupMembers', $myGroupMembers, SQ_POST);
+sqgetGlobalVar('abookGroups', $abookGroups, SQ_POST);
+sqgetGlobalVar('remove', $remove, SQ_POST);
+sqgetGlobalVar('name', $name, SQ_POST);
+sqgetGlobalVar('nickName', $nickName, SQ_POST);
+sqgetGlobalVar('backendName', $backendName, SQ_POST);
+
+/* End globals */
+
 displayPageHeader($color, $mailbox);
 
 /* Initialize addressbook */
