@@ -7,7 +7,7 @@
  *
  * List abook groups for modify, delete or to list group members.
  */
-define('SM_PATH','../../');
+if (!defined('SM_PATH'))define('SM_PATH','../../');
 
 include_once(SM_PATH . 'include/validate.php');
 include_once(SM_PATH . 'functions/addressbook.php');
@@ -15,6 +15,19 @@ include_once(SM_PATH . 'plugins/abook_group/abook_group_database.php');
 include_once(SM_PATH . 'plugins/abook_group/abook_group_functions.php');
 
 global $mailbox, $username;
+
+/*  Start globals  */
+
+sqgetGlobalVar('username', $username, SQ_POST);
+sqgetGlobalVar('mailbox', $mailbox, SQ_POST);
+sqgetGlobalVar('myparams', $myparams, SQ_POST);
+sqgetGlobalVar('abookGroups', $abookGroups, SQ_POST);
+sqgetGlobalVar('myGroups', $myGroups, SQ_POST);
+sqgetGlobalVar('groupName', $groupName, SQ_POST);
+sqgetGlobalVar('groupNameURL', $groupNameURL, SQ_POST);
+
+/*  End globals  */
+
 displayPageHeader($color, $mailbox);
 
 /* Initialize addressbook */
@@ -25,7 +38,6 @@ $myparams['table'] = 'addressgroups';
 $myparams['owner'] = $username;
 
 $abookGroups = new abook_group_database($myparams);
-
 $myGroups = $abookGroups->list_group();
 
 ?>
