@@ -9,7 +9,7 @@
  * script to modify group
  *
  */
-define('SM_PATH','../../');
+if (!defined('SM_PATH'))define('SM_PATH','../../');
 
 include_once(SM_PATH . 'include/validate.php');
 include_once(SM_PATH . 'functions/display_messages.php');
@@ -21,6 +21,22 @@ include_once(SM_PATH . 'plugins/abook_group/abook_group_functions.php');
 
 global $mailbox, $username;
 
+/*  Start globals */
+
+sqgetGlobalVar('abook', $abook, SQ_POST);
+sqgetGlobalVar('mailbox', $mailbox, SQ_POST);
+sqgetGlobalVar('username', $username, SQ_POST);
+sqgetGlobalVar('color', $color, SQ_POST);
+sqgetGlobalVar('myparams', $myparams, SQ_POST);
+sqgetGlobalVar('message', $message, SQ_POST);
+sqgetGlobalVar('groupName', $groupName, SQ_GET);
+sqgetGlobalVar('opt', $opt, SQ_GET);
+sqgetGlobalVar('opt', $opt, SQ_POST);
+sqgetGlobalVar('abookGroups', $abookGroups, SQ_POST);
+sqgetGlobalVar('newGroupName', $newGroupName, SQ_POST);
+
+/*  End globals */
+
 /* Initialize addressbook */
 $abook = addressbook_init();
 
@@ -52,7 +68,6 @@ if ($opt!="edit"){
 }
 
 displayPageHeader($color, $mailbox);
-
 ?>
 
 <table width="95%" align=center cellpadding=2 cellspacing=2 border=0>
