@@ -13,11 +13,19 @@
         /* Standard initialization API. */
         global $squirrelmail_plugin_hooks;
 
-        $squirrelmail_plugin_hooks['compose_button_row']['abook_group'] = 'abook_group_setup';
-        $squirrelmail_plugin_hooks['optpage_register_block']['abook_group'] = 'abook_group_optpage_register_block';
-        $squirrelmail_plugin_hooks['options_link_and_description']['abook_group'] = 'abook_group_options';
+        $squirrelmail_plugin_hooks['compose_button_row']['abook_group'] = 
+           'abook_group_setup';
+        $squirrelmail_plugin_hooks['optpage_register_block']['abook_group'] = 
+           'abook_group_optpage_register_block';
+        $squirrelmail_plugin_hooks['options_link_and_description']['abook_group'] = 
+           'abook_group_options';
     }
 
+    function abook_group_version() {
+       return '0.21';
+    }
+
+
     function abook_group_optpage_register_block() {
        // Gets added to the user's OPTIONS page.
        global $optpage_blocks;
@@ -27,13 +35,14 @@
            /* Register abook_group with the $optionpages array. */
            $optpage_blocks[] = array(
                'name' => _("Address Groups"),
-               'url'  => '../plugins/abook_group/list_abook_group.php',
+               'url'  => SM_PATH . 'plugins/abook_group/list_abook_group.php',
                'desc' => _("You can create address groups and add email addresses from your address book"),
                'js'   => FALSE
             );
         }
     }
 
+
     function abook_group_setup() {
         /* Gets added to the COMPOSE buttons row. */
         if ( !soupNazi() ) {
